<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!-- Translator is a stylesheet that accepts a .wpo translation file
 as parameter, and produces -->
<!-- a translated version of the file in input -->

<!-- example of use: 
 xsl-c -XSL translator.xsl -IN ../examples/dns.naat -PARAM wpofile "'tmp'" (prints on the stdout)-->

<xsl:param name="wpofile"/>

<xsl:output method="xml" encoding="iso-8859-1" indent="yes"/>

<xsl:template match="/">
<![CDATA[
<!DOCTYPE Wizard SYSTEM "dtd/Naat.dtd"[
<!ENTITY % help-pages SYSTEM "help-pages/index.ent">
%help-pages;
]>
]]>

  <xsl:copy>
  	<xsl:apply-templates/>
  </xsl:copy>
</xsl:template>

<xsl:template match="HelpPage[@name]">
<!--
<xsl:for-each select="//Page[@helpURL]">
-->
<xsl:text disable-output-escaping="yes">&amp;help-</xsl:text><xsl:value-of select="@name"/><xsl:text>;
</xsl:text>
<!--
</xsl:for-each>
-->
</xsl:template>


<xsl:template match="*|@*|comment()|processing-instruction()">
  <xsl:copy>
  <xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()"/>
  </xsl:copy>

</xsl:template>


<!-- classical  Node traduction  -->
<xsl:template match="Introduction|Description|Title|Label|Point|Option">
 <xsl:copy>
	<xsl:apply-templates select="*|@*"/>
		<xsl:call-template name="routine">
		    <xsl:with-param name="fromtext">
		      <xsl:value-of select="."/>
		    </xsl:with-param>
		</xsl:call-template>
 </xsl:copy>
</xsl:template>

<!-- specific  attribute traduction -->
<xsl:template match="Dynfield|DynAttribut">
<xsl:copy>
	<xsl:apply-templates select="@*"/>
	<xsl:attribute name="label" >
		<xsl:call-template name="routine">
			<xsl:with-param name="fromtext">
				<xsl:value-of select="@label"/>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:attribute>
	<xsl:apply-templates />
</xsl:copy>
</xsl:template>

<!-- specific  attribute traduction -->
<xsl:template match="ParamAction|Button">
<xsl:copy>
	<xsl:apply-templates select="@*"/>
	<xsl:attribute name="value">
		<xsl:call-template name="routine">
			<xsl:with-param name="fromtext">
				<xsl:value-of select="@value"/>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:attribute>
	<xsl:apply-templates />
</xsl:copy>
</xsl:template>


<!-- the actual translation routine  -->
<xsl:template name="routine">
  <xsl:param name="fromtext"/>
  <xsl:choose>
<!-- if a translation exists for the given fromtext, insert the translation... -->
<!--(this test accesses the translation file twice: can we do better?) -->
    <xsl:when test="document($wpofile)//*/from[text()=$fromtext]/../to and string-length(document($wpofile)//*/from[text()=$fromtext]/../to)>0">
      <xsl:value-of select="document($wpofile)//*/from[text()=$fromtext]/../to"/>
    </xsl:when>
<!-- otherwise leave the english version -->
    <xsl:otherwise>
	<xsl:value-of select="$fromtext"/>
	<xsl:message>
TODO	in <xsl:value-of select="$wpofile"/> : <xsl:value-of select="$fromtext"/>
	</xsl:message>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="text()">
	<xsl:value-of select="."/>
</xsl:template>
</xsl:stylesheet>
